# -*- coding: utf-8 -*-

import os
import glob
import random
from io import StringIO

import click
from rich.console import Console
from rich.markdown import Markdown


def validate_number(ctx, param, value):
    try:
        _ = int(value)
        return value
    except ValueError:
        if value == "random":
            return value
        else:
            raise click.BadParameter("Argument should be an integer or 'random'")


@click.command("opep")
@click.argument("number", callback=validate_number)
@click.pass_context
def cli(*args, **kwargs):
    """Open PEPs on your terminal."""
    number = kwargs["number"]

    cwd = os.path.dirname(__file__)
    if number == "random":
        pep_path = random.choice(glob.glob(os.path.join(cwd, "peps/*.md")))
    else:
        pep_path = os.path.join(cwd, f"peps/pep-{number.zfill(4)}.md")

    with open(pep_path, "r") as f:
        pep_content = f.read()

    # https://github.com/willmcgugan/rich/issues/77#issuecomment-670659857
    console = Console(file=StringIO(), force_terminal=True)

    md = Markdown(pep_content)
    console.print(md)

    click.echo_via_pager(console.file.getvalue())



# -*- coding: utf-8 -*-

import os
from setuptools import find_packages


here = os.path.abspath(os.path.dirname(__file__))
about = {}
with open(os.path.join(here, "opep", "__version__.py"), "r") as f:
    exec(f.read(), about)

with open("README.md", "r") as f:
    readme = f.read()


requires = [
    "Click>=7.0",
    "rich==7.0.0",
]
dev_requires = ["Sphinx>=2.2.1"]
dev_requires = dev_requires + requires


def setup_package():
    metadata = dict(
        name=about["__title__"],
        version=about["__version__"],
        description=about["__description__"],
        long_description=readme,
        long_description_content_type="text/markdown",
        url=about["__url__"],
        author=about["__author__"],
        author_email=about["__author_email__"],
        license=about["__license__"],
        packages=find_packages(exclude=("tests",)),
        entry_points={
            "console_scripts": [
                "opep = opep.cli:cli"
            ]
        },
        install_requires=requires,
        extras_require={"dev": dev_requires},
        classifiers=[
            # Trove classifiers
            # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
            "License :: OSI Approved :: Apache Software License",
            "Programming Language :: Python :: 3.6",
            "Programming Language :: Python :: 3.7",
        ],
    )

    try:
        from setuptools import setup
    except ImportError:
        from distutils.core import setup

    setup(**metadata)


if __name__ == "__main__":
    setup_package()
